@@ -8,18 +8,18 @@ from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.support.select import Select
 import unittest, time, logging, os, inspect
-from src.python_selenium_ctrl_package.Base_Logging import Base_Logging
-from src.python_selenium_ctrl_package.BrowserStack_Library import BrowserStack_Library
-from src.python_selenium_ctrl_package.driverfactory import DriverFactory
+from ..utils.general.Base_Logging import Base_Logging
+from ..remoteTest.BrowserStack_Library import BrowserStack_Library
+from ..drivers.driverfactory import DriverFactory
 # from utils.Test_Rail import Test_Rail
 # from utils import Tesults
-from src.python_selenium_ctrl_package.stop_test_exception_util import Stop_Test_Exception
-from src.python_selenium_ctrl_package import remote_credentials
-from src.python_selenium_ctrl_package import base_url_conf
-from src.python_selenium_ctrl_package import screenshot_conf
-from src.python_selenium_ctrl_package import Gif_Maker
+from ..utils.general.stop_test_exception_util import Stop_Test_Exception
+from ..utils import remote_credentials
+from ..conf.rwd.Website import base_url_conf
+from ..utils import screenshot_conf
+from ..utils.general import Gif_Maker
 from datetime import datetime
-from src.python_selenium_ctrl_package.Wrapit import Wrapit
+from ..utils.general.Wrapit import Wrapit
 
 
 class Borg:
@@ -183,14 +183,14 @@ class Base_Page(Borg, unittest.TestCase):
 
         return self.calling_module
 
-    def set_directory_structure(self):
+    def set_directory_structure(self, invocation_dir):
         "Setup the required directory structure if it is not already present"
         try:
             self.screenshots_parent_dir = os.path.abspath(
                 os.path.join(os.path.dirname(__file__), '../../../..', 'screenshots', self.product))  # Real screencap folder dir
             if not os.path.exists(self.screenshots_parent_dir):
                 os.makedirs(self.screenshots_parent_dir)
-            self.logs_parent_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '../../../..', 'log',
+            self.logs_parent_dir = os.path.abspath(os.path.join(invocation_dir.strpath, '../../../..', 'log',
                                                                 self.product))          # Real log file dir base on Base_Logging.py constructor
             if not os.path.exists(self.logs_parent_dir):
                 os.makedirs(self.logs_parent_dir)
